@@ -62,7 +62,6 @@ shinyServer(function(input, output) {
       }
       
     }
-    print(matches)
     
     if (length(matches) == 0) {
       return("Predictor combination untested.")
@@ -85,4 +84,8 @@ shinyServer(function(input, output) {
                "At higher credible levels, no conclusion may be drawn."))
     }
   })
+  
+  observeEvent(input$closeApp, {
+    stopApp()
+  })
 })
